@@ -18,7 +18,7 @@ class Migration(migrations.Migration):
                 ('name', models.CharField(max_length=50, verbose_name='display name')),
             ],
             options={
-                'ordering': ('domain',),
+                'ordering': ['domain'],
                 'db_table': 'django_site',
                 'verbose_name': 'site',
                 'verbose_name_plural': 'sites',
